@@ -220,8 +220,85 @@ static SSLConnRec *nss_init_connection_ctx(conn_rec *c)
     return sslconn;
 }
 
+static int nss_engine_status(conn_rec *c, SSLConnRec *sslconn)
+{
+    SSLSrvConfigRec *sc = mySrvConfig(c->base_server);
+
+    if (c->master) {
+        return DECLINED;
+    }
+    if (sslconn) {
+        if (sslconn->disabled) {
+            return SUSPENDED;
+        }
+        if (sslconn->is_proxy) {
+            if (!sc->proxy_enabled) {
+                return DECLINED;
+            }
+        }
+        else {
+            if (sc->enabled != TRUE) {
+                return DECLINED;
+            }
+        }
+    }
+    else {
+        if (sc->enabled != TRUE) {
+            return DECLINED;
+        }
+    }
+    return OK;
+}
+
 static APR_OPTIONAL_FN_TYPE(ssl_proxy_enable) *othermod_proxy_enable;
 static APR_OPTIONAL_FN_TYPE(ssl_engine_disable) *othermod_engine_disable;
+#ifdef SSL_ENGINE_SET
+static APR_OPTIONAL_FN_TYPE(ssl_engine_set) *othermod_engine_set;
+
+int nss_engine_set(conn_rec *c,
+                   ap_conf_vector_t *per_dir_config,
+                   int proxy, int enable)
+{
+    SSLConnRec *sslconn;
+    int status;
+
+    if (othermod_engine_set) {
+        return othermod_engine_set(c, per_dir_config, proxy, enable);
+    }
+
+    // FIXME: Add support for per_dir_config
+    if (proxy) {
+        sslconn = nss_init_connection_ctx(c);
+        sslconn->is_proxy = 1;
+    }
+    else {
+        sslconn = myConnConfig(c);
+    }
+
+    status = nss_engine_status(c, sslconn);
+
+    if (proxy && status == DECLINED) {
+        if (enable) {
+            SSLSrvConfigRec *sc = mySrvConfig(c->base_server);
+            ap_log_cerror(APLOG_MARK, APLOG_ERR, 0, c, APLOGNO(01961)
+                          "SSL Proxy requested for %s but not enabled "
+                          "[Hint: SSLProxyEngine]", sc->vhost_id);
+        }
+        sslconn->disabled = 1;
+    }
+    else if (sslconn) {
+        sslconn->disabled = !enable;
+    }
+
+    return status != DECLINED;
+}
+
+static int ssl_engine_set(conn_rec *c,
+                          ap_conf_vector_t *per_dir_config,
+                          int proxy, int enable) {
+    return nss_engine_set(c, per_dir_config, proxy, enable);
+}
+#endif
 
 int nss_proxy_enable(conn_rec *c)
 {
@@ -503,14 +580,23 @@ static void nss_register_hooks(apr_pool_t *p)
     /* Always register these mod_nss optional functions */
     APR_REGISTER_OPTIONAL_FN(nss_proxy_enable);
     APR_REGISTER_OPTIONAL_FN(nss_engine_disable);
+#ifdef SSL_ENGINE_SET
+    APR_REGISTER_OPTIONAL_FN(nss_engine_set);
+#endif
 
     /* Save the state of any previously registered mod_ssl functions */
     othermod_proxy_enable = APR_RETRIEVE_OPTIONAL_FN(ssl_proxy_enable);
     othermod_engine_disable = APR_RETRIEVE_OPTIONAL_FN(ssl_engine_disable);
+#ifdef SSL_ENGINE_SET
+    othermod_engine_set = APR_RETRIEVE_OPTIONAL_FN(ssl_engine_set);
+#endif
 
     /* Always register these local mod_ssl optional functions */
     APR_REGISTER_OPTIONAL_FN(ssl_proxy_enable);
     APR_REGISTER_OPTIONAL_FN(ssl_engine_disable);
+#ifdef SSL_ENGINE_SET
+    APR_REGISTER_OPTIONAL_FN(ssl_engine_set);
+#endif
 }
 
 module AP_MODULE_DECLARE_DATA nss_module = {
