@@ -45,13 +45,6 @@ char* INTERNAL_TOKEN_NAME = "internal                         ";
 
 extern cipher_properties ciphers_def[];
 
-static char *version_components[] = {
-    "SSL_VERSION_PRODUCT",
-    "SSL_VERSION_INTERFACE",
-    "SSL_VERSION_LIBRARY",
-    NULL
-};
-
 /* See if a uid or gid can read a file or directory at a given path.
  *
  * Return 0 on failure or file doesn't exist
@@ -109,19 +102,17 @@ static char *nss_add_version_component(apr_pool_t *p,
 static void nss_add_version_components(apr_pool_t *p,
                                        server_rec *s)
 {
-    char *vals[sizeof(version_components)/sizeof(char *)];
-    int i;
+    char *interface, *library;
 
-    for (i=0; version_components[i]; i++) {
-        vals[i] = nss_add_version_component(p, s,
-                                            version_components[i]);
-    }
+    nss_add_version_component(p, s, "SSL_VERSION_PRODUCT");
+    interface = nss_add_version_component(p, s, "SSL_VERSION_INTERFACE");
+    library = nss_add_version_component(p, s, "SSL_VERSION_LIBRARY");
 
     ap_log_error(APLOG_MARK, APLOG_INFO, 0, s,
                  "Server: %s, Interface: %s, Library: %s",
                  AP_SERVER_BASEVERSION,
-                 vals[1],  /* SSL_VERSION_INTERFACE */
-                 vals[2]); /* SSL_VERSION_LIBRARY */
+                 interface,
+                 library);
 }
 
 /*
@@ -773,7 +764,7 @@ static void nss_init_ctx_protocol(server_rec *s,
     char *protocol_marker = NULL;
     char *lprotocols = NULL;
     SECStatus stat;
-    SSLVersionRange enabledVersions;
+    SSLVersionRange enabledVersions = {0,0};
 
     ssl3 = tls = tls1_1 = tls1_2 = 0;
 
