@@ -266,7 +266,7 @@ char *nss_var_lookup(apr_pool_t *p, server_rec *s, conn_rec *c, request_rec *r,
             resdup = FALSE;
         }
         /* all other env-variables from the parent Apache process */
-        else if (strlen(var) > 4 && strcEQn(var, "ENV:", 4)) {
+        else if ((r != NULL) && strlen(var) > 4 && strcEQn(var, "ENV:", 4)) {
             result = (char *)apr_table_get(r->notes, var+4);
             if (result == NULL)
                 result = (char *)apr_table_get(r->subprocess_env, var+4);
